dls-bxflow
=======================================================================

Distributed beamline automated data processing workflow engine and gui platform core.

Support beamline-specific science algorithms as workflow tasks.

For documentation see: https://diamondlightsource.github.io/dls-bxflow